@@ -21,12 +21,16 @@ import re
 import os
 import sys
 
+import difflib
 import inspect
 import traceback
 
 from functools import wraps
 from datetime import datetime
 
+from six import string_types, text_type, PY3, get_function_code
+from six.moves import reduce
+
 from sure.old import AssertionHelper
 from sure.old import Iterable
 from sure.old import builtins
@@ -39,14 +43,12 @@ from sure.core import safe_repr
 
 from sure.magic import is_cpython, patchable_builtin
 from sure.registry import context as _registry
-from sure.six import string_types, text_type, PY3, get_function_code
-from sure.six.moves import reduce
 
 
 if PY3:
     basestring = str
 
-version = '1.2.4'
+version = '1.2.7'
 
 
 not_here_error = \
@@ -89,7 +91,7 @@ class VariablesBag(dict):
 
 
 class CallBack(object):
-    context_error = u"the function %s defined at %s line %d, is being "\
+    context_error = "the function %s defined at %s line %d, is being "\
         "decorated by either @that_with_context or @scenario, so it should " \
         "take at least 1 parameter, which is the test context"
 
@@ -178,9 +180,9 @@ def within(**units):
             except TypeError as e:
                 if PY3:
                     # PY3 has different error message
-                    fmt = u'{0}() takes 0 positional arguments but 1 was given'
+                    fmt = '{0}() takes 0 positional arguments but 1 was given'
                 else:
-                    fmt = u'{0}() takes no arguments'
+                    fmt = '{0}() takes no arguments'
                 err = text_type(e)
                 if fmt.format(func.__name__) in err:
                     func(*args, **kw)
@@ -225,10 +227,10 @@ UNITS = {
     ),
 }
 
-milisecond = miliseconds = u'miliseconds'
-microsecond = microseconds = u'microseconds'
-second = seconds = u'seconds'
-minute = minutes = u'minutes'
+milisecond = miliseconds = 'miliseconds'
+microsecond = microseconds = 'microseconds'
+second = seconds = 'seconds'
+minute = minutes = 'minutes'
 
 
 def word_to_number(word):
@@ -299,12 +301,12 @@ def action_for(context, provides=None, depends_on=None):
             'into the context, but it did not. Please double check its ' \
             'implementation' % (func.__name__, attr)
 
-    dependency_error_lonely = u'the action "%s" defined at %s:%d ' \
+    dependency_error_lonely = 'the action "%s" defined at %s:%d ' \
         'depends on the attribute "%s" to be available in the' \
         ' context. It turns out that there are no actions providing ' \
         'that. Please double-check the implementation'
 
-    dependency_error_hints = u'the action "%s" defined at %s:%d ' \
+    dependency_error_hints = 'the action "%s" defined at %s:%d ' \
         'depends on the attribute "%s" to be available in the context.'\
         ' You need to call one of the following actions beforehand:\n'
 
@@ -429,6 +431,7 @@ class AssertionBuilder(object):
     def __init__(self, name=None, negative=False, obj=None):
         self._name = name
         self.negative = negative
+
         self.obj = obj
         self._callable_args = []
         self._callable_kw = {}
@@ -467,11 +470,6 @@ class AssertionBuilder(object):
 
     @assertionproperty
     def be(self):
-        import os
-        if os.getenv("DEBUG"):
-            import ipdb;ipdb.set_trace()
-
-
         return IdentityAssertion(self)
 
     being = be
@@ -538,20 +536,20 @@ class AssertionBuilder(object):
         length = len(self.obj)
         if self.negative:
             assert length > 0, (
-                u"expected `{0}` to not be empty".format(representation))
+                "expected `{0}` to not be empty".format(representation))
         else:
             assert length == 0, (
-                u"expected `{0}` to be empty but it has {1} items".format(representation, length))
+                "expected `{0}` to be empty but it has {1} items".format(representation, length))
 
         return True
 
     @assertionproperty
     def ok(self):
         if self.negative:
-            msg = u'expected `{0}` to be falsy'.format(self.obj)
+            msg = 'expected `{0}` to be falsy'.format(self.obj)
             assert not bool(self.obj), msg
         else:
-            msg = u'expected `{0}` to be truthy'.format(self.obj)
+            msg = 'expected `{0}` to be truthy'.format(self.obj)
             assert bool(self.obj), msg
 
         return True
@@ -562,10 +560,10 @@ class AssertionBuilder(object):
     @assertionproperty
     def falsy(self):
         if self.negative:
-            msg = u'expected `{0}` to be truthy'.format(self.obj)
+            msg = 'expected `{0}` to be truthy'.format(self.obj)
             assert bool(self.obj), msg
         else:
-            msg = u'expected `{0}` to be falsy'.format(self.obj)
+            msg = 'expected `{0}` to be falsy'.format(self.obj)
             assert not bool(self.obj), msg
 
         return True
@@ -624,6 +622,23 @@ class AssertionBuilder(object):
     equals = equal
     equal_to = equal
 
+    @assertionmethod
+    def different_of(self, what):
+        differ = difflib.Differ()
+
+        source = self.obj.strip().splitlines(True)
+        destination = what.strip().splitlines(True)
+        result = differ.compare(source, destination)
+        difference = "".join(result)
+        if self.negative:
+            if self.obj != what:
+                assert not difference, "Difference:\n\n{0}".format(difference)
+        else:
+            if self.obj == what:
+                raise AssertionError("{0} should be different of {1}".format(self.obj, what))
+
+        return True
+
     @assertionmethod
     def an(self, klass):
         if isinstance(klass, type):
@@ -644,9 +659,9 @@ class AssertionBuilder(object):
                     first = '_abcoll'
             else:
                 if sys.version_info <= (3, 0, 0):
-                    first = u'__builtin__'
+                    first = '__builtin__'
                 else:
-                    first = u'builtins'
+                    first = 'builtins'
                 items = [klass]
 
             klass = reduce(getattr, items, __import__(first))
@@ -669,13 +684,13 @@ class AssertionBuilder(object):
     @assertionmethod
     def greater_than(self, dest):
         if self.negative:
-            msg = u"expected `{0}` to not be greater than `{1}`".format(
+            msg = "expected `{0}` to not be greater than `{1}`".format(
                 self.obj, dest)
 
             assert not self.obj > dest, msg
 
         else:
-            msg = u"expected `{0}` to be greater than `{1}`".format(
+            msg = "expected `{0}` to be greater than `{1}`".format(
                 self.obj, dest)
             assert self.obj > dest, msg
 
@@ -684,13 +699,13 @@ class AssertionBuilder(object):
     @assertionmethod
     def greater_than_or_equal_to(self, dest):
         if self.negative:
-            msg = u"expected `{0}` to not be greater than or equal to `{1}`".format(
+            msg = "expected `{0}` to not be greater than or equal to `{1}`".format(
                 self.obj, dest)
 
             assert not self.obj >= dest, msg
 
         else:
-            msg = u"expected `{0}` to be greater than or equal to `{1}`".format(
+            msg = "expected `{0}` to be greater than or equal to `{1}`".format(
                 self.obj, dest)
             assert self.obj >= dest, msg
 
@@ -699,13 +714,13 @@ class AssertionBuilder(object):
     @assertionmethod
     def lower_than(self, dest):
         if self.negative:
-            msg = u"expected `{0}` to not be lower than `{1}`".format(
+            msg = "expected `{0}` to not be lower than `{1}`".format(
                 self.obj, dest)
 
             assert not self.obj < dest, msg
 
         else:
-            msg = u"expected `{0}` to be lower than `{1}`".format(
+            msg = "expected `{0}` to be lower than `{1}`".format(
                 self.obj, dest)
             assert self.obj < dest, msg
 
@@ -714,13 +729,13 @@ class AssertionBuilder(object):
     @assertionmethod
     def lower_than_or_equal_to(self, dest):
         if self.negative:
-            msg = u"expected `{0}` to not be lower than or equal to `{1}`".format(
+            msg = "expected `{0}` to not be lower than or equal to `{1}`".format(
                 self.obj, dest)
 
             assert not self.obj <= dest, msg
 
         else:
-            msg = u"expected `{0}` to be lower than or equal to `{1}`".format(
+            msg = "expected `{0}` to be lower than or equal to `{1}`".format(
                 self.obj, dest)
             assert self.obj <= dest, msg
 
@@ -729,10 +744,10 @@ class AssertionBuilder(object):
     @assertionmethod
     def below(self, num):
         if self.negative:
-            msg = u"{0} should not be below {1}".format(self.obj, num)
+            msg = "{0} should not be below {1}".format(self.obj, num)
             assert not self.obj < num, msg
         else:
-            msg = u"{0} should be below {1}".format(self.obj, num)
+            msg = "{0} should be below {1}".format(self.obj, num)
             assert self.obj < num, msg
 
         return True
@@ -740,10 +755,10 @@ class AssertionBuilder(object):
     @assertionmethod
     def above(self, num):
         if self.negative:
-            msg = u"{0} should not be above {1}".format(self.obj, num)
+            msg = "{0} should not be above {1}".format(self.obj, num)
             assert not self.obj > num, msg
         else:
-            msg = u"{0} should be above {1}".format(self.obj, num)
+            msg = "{0} should be above {1}".format(self.obj, num)
             assert self.obj > num, msg
         return True
 
@@ -769,7 +784,7 @@ class AssertionBuilder(object):
                      and_kwargs=self._callable_kw)
 
         if self.negative:
-            msg = (u"{0} called with args {1} and kwargs {2} should "
+            msg = ("{0} called with args {1} and kwargs {2} should "
                    "not raise {3} but raised {4}")
 
             exc = args and args[0] or Exception
@@ -876,10 +891,10 @@ if is_cpython and allows_new_syntax:
         def method(self):
             builder = AssertionBuilder(name, negative=False)
             instance = builder(self)
-            callable_args = getattr(instance, '_callable_args', ())
+            callable_args = getattr(self, '_callable_args', ())
             if callable_args:
                 instance._callable_args = callable_args
-            callable_kw = getattr(instance, '_callable_kw', {})
+            callable_kw = getattr(self, '_callable_kw', {})
             if callable_kw:
                 instance._callable_kw = callable_kw
             return instance
@@ -891,10 +906,10 @@ if is_cpython and allows_new_syntax:
         def method(self):
             builder = AssertionBuilder(name, negative=True)
             instance = builder(self)
-            callable_args = getattr(instance, '_callable_args', ())
+            callable_args = getattr(self, '_callable_args', ())
             if callable_args:
                 instance._callable_args = callable_args
-            callable_kw = getattr(instance, '_callable_kw', {})
+            callable_kw = getattr(self, '_callable_kw', {})
             if callable_kw:
                 instance._callable_kw = callable_kw
             return instance
