@@ -18,6 +18,7 @@
 from __future__ import unicode_literals
 
 import re
+import traceback
 import inspect
 from copy import deepcopy
 from pprint import pformat
@@ -32,11 +33,12 @@ try:
 except ImportError:
     import builtins
 
+from six import string_types, text_type
+
 from sure.core import DeepComparison
 from sure.core import _get_file_name
 from sure.core import _get_line_number
 from sure.core import itemize_length
-from sure.six import string_types, text_type
 
 
 def is_iterable(obj):
@@ -118,14 +120,14 @@ class AssertionHelper(object):
             if isinstance(exc, string_types):
                 msg = exc
                 exc = type(e)
-            
+
             err = text_type(e)
 
             if isinstance(exc, type) and issubclass(exc, BaseException):
                 if not isinstance(e, exc):
                     raise AssertionError(
-                        '%r should raise %r, but raised %r' % (
-                            self._src, exc, e.__class__))
+                        '%r should raise %r, but raised %r:\nORIGINAL EXCEPTION:\n\n%s' % (
+                            self._src, exc, e.__class__, traceback.format_exc(e)))
 
                 if isinstance(msg, string_types) and msg not in err:
                     raise AssertionError('''
@@ -176,7 +178,7 @@ class AssertionHelper(object):
 
     def equals(self, dst):
         if self._attribute and is_iterable(self._src):
-            msg = u'%r[%d].%s should be %r, but is %r'
+            msg = '%r[%d].%s should be %r, but is %r'
 
             for index, item in enumerate(self._src):
                 if self._range:
@@ -198,12 +200,12 @@ class AssertionHelper(object):
         old_dst = pformat(dst)
         self._src = re.sub(r'\s', '', self._src).lower()
         dst = re.sub(r'\s', '', dst).lower()
-        error = u'%s does not look like %s' % (old_src, old_dst)
+        error = '%s does not look like %s' % (old_src, old_dst)
         assert self._src == dst, error
         return self._src == dst
 
     def every_one_is(self, dst):
-        msg = u'all members of %r should be %r, but the %dth is %r'
+        msg = 'all members of %r should be %r, but the %dth is %r'
         for index, item in enumerate(self._src):
             if self._range:
                 if index < self._range[0] or index > self._range[1]:
@@ -247,7 +249,7 @@ class AssertionHelper(object):
         length = len(self._src)
 
         if length <= that:
-            error = u'the length of the %s should be greater then %d, but is %d' % (
+            error = 'the length of the %s should be greater then %d, but is %d' % (
                 type(self._src).__name__,
                 that,
                 length,
@@ -262,7 +264,7 @@ class AssertionHelper(object):
         length = len(self._src)
 
         if length < that:
-            error = u'the length of %r should be greater then or equals %d, but is %d' % (
+            error = 'the length of %r should be greater then or equals %d, but is %d' % (
                 self._src,
                 that,
                 length,
@@ -280,7 +282,7 @@ class AssertionHelper(object):
         length = len(self._src)
 
         if length >= that:
-            error = u'the length of %r should be lower then %r, but is %d' % (
+            error = 'the length of %r should be lower then %r, but is %d' % (
                 self._src,
                 original_that,
                 length,
@@ -293,7 +295,7 @@ class AssertionHelper(object):
         that = self._get_that(that)
 
         length = len(self._src)
-        error = u'the length of %r should be lower then or equals %d, but is %d'
+        error = 'the length of %r should be lower then or equals %d, but is %d'
 
         if length > that:
             msg = error % (
@@ -310,7 +312,7 @@ class AssertionHelper(object):
         length = len(self._src)
 
         if length != that:
-            error = u'the length of %r should be %d, but is %d' % (
+            error = 'the length of %r should be %d, but is %d' % (
                 self._src,
                 that,
                 length,
@@ -324,7 +326,7 @@ class AssertionHelper(object):
         length = len(self._src)
 
         if length == that:
-            error = u'the length of %r should not be %d' % (
+            error = 'the length of %r should not be %d' % (
                 self._src,
                 that,
             )
@@ -344,7 +346,7 @@ class AssertionHelper(object):
         return self
 
     def matches(self, items):
-        msg = u'%r[%d].%s should be %r, but is %r'
+        msg = '%r[%d].%s should be %r, but is %r'
         get_eval = lambda item: eval(
             "%s.%s" % ('current', self._eval), {}, {'current': item},
         )
